﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WebEdition;
using System.Configuration;
using System.Data;
using System.Data.Common;
using Microsoft.Practices.EnterpriseLibrary.Common;
using Microsoft.Practices.EnterpriseLibrary.Data;
using System.Collections.ObjectModel;



    public partial class map : System.Web.UI.Page
    {

        protected void Page_Load(object sender, EventArgs e)
        {

            Map1.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.FromHtml("#CCCCFF"));
            Map1.MapUnit = GeographyUnit.Meter;

            //Adds the Google Map as an overlay
            GoogleOverlay google = new GoogleOverlay("Google Map");
            google.JavaScriptLibraryUri = new Uri(ConfigurationManager.AppSettings["GoogleUri"]);
            google.GoogleMapType = GoogleMapType.Normal;
            Map1.CustomOverlays.Add(google);

            //Sets the projection parameters to go from Geodetic (EPSG 4326) or decimal degrees to Google Map projection (Spherical Mercator).
            Proj4Projection proj4 = new Proj4Projection();
            proj4.InternalProjectionParametersString = Proj4Projection.GetEpsgParametersString(4326);
            proj4.ExternalProjectionParametersString = Proj4Projection.GetGoogleMapParametersString();

            LayerOverlay phOverlay = new LayerOverlay("PhOverlay", false, TileType.SingleTile);
            phOverlay.TransitionEffect = TransitionEffect.None;

            String shapeFilePath = Server.MapPath(@"~/ShapeFiles/BrackleypH2007Grid_region.shp").ToString();


            ShapeFileFeatureLayer worldLayer = new ShapeFileFeatureLayer(shapeFilePath);

            worldLayer.FeatureSource.Projection = proj4;
            phOverlay.Layers.Add(worldLayer);
            Map1.CustomOverlays.Add(phOverlay);

            worldLayer.Open();
            Map1.CurrentExtent = worldLayer.GetBoundingBox();
            Map1.ZoomLevelSet = worldLayer.ZoomLevelSet;

            worldLayer.Close();

            ClassBreakStyle classBreakStyle = new ClassBreakStyle("Ph");
            classBreakStyle.ClassBreaks.Add(new ClassBreak(5.4, AreaStyles.CreateSimpleAreaStyle(GeoColor.StandardColors.Blue, GeoColor.StandardColors.Black)));
            classBreakStyle.ClassBreaks.Add(new ClassBreak(5.7, AreaStyles.CreateSimpleAreaStyle(GeoColor.StandardColors.LightBlue, GeoColor.StandardColors.Black)));
            classBreakStyle.ClassBreaks.Add(new ClassBreak(6.0, AreaStyles.CreateSimpleAreaStyle(GeoColor.StandardColors.Turquoise, GeoColor.StandardColors.Black)));
            classBreakStyle.ClassBreaks.Add(new ClassBreak(6.2, AreaStyles.CreateSimpleAreaStyle(GeoColor.StandardColors.LightGreen, GeoColor.StandardColors.Black)));
            classBreakStyle.ClassBreaks.Add(new ClassBreak(6.6, AreaStyles.CreateSimpleAreaStyle(GeoColor.StandardColors.Yellow, GeoColor.StandardColors.Black)));
            classBreakStyle.ClassBreaks.Add(new ClassBreak(7.0, AreaStyles.CreateSimpleAreaStyle(GeoColor.StandardColors.Orange, GeoColor.StandardColors.Black)));
            classBreakStyle.ClassBreaks.Add(new ClassBreak(9.0, AreaStyles.CreateSimpleAreaStyle(GeoColor.StandardColors.Red, GeoColor.StandardColors.Black)));

            worldLayer.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(classBreakStyle);
            worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            worldLayer.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(classBreakStyle);


            worldLayer.ZoomLevelSet.ZoomLevel16.CustomStyles.Add(classBreakStyle);
            worldLayer.ZoomLevelSet.ZoomLevel16.CustomStyles.Add(TextStyles.CreateSimpleTextStyle("Ph", "Arial", 12, DrawingFontStyles.Bold, GeoColor.StandardColors.Black, 0, 0));
            worldLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle.SuppressPartialLabels = true;
            worldLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle.DuplicateRule = LabelDuplicateRule.UnlimitedDuplicateLabels;
            worldLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.AllowOverlapping;
            worldLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle.GridSize = 10;
            worldLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle.BestPlacement = true;

            worldLayer.ZoomLevelSet.ZoomLevel16.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            worldLayer.DrawingMarginPercentage = 50;

       
        }
    }
